@@ -26,6 +26,7 @@ import com.google.gwt.uibinder.client.UiBinder;
 import com.google.gwt.uibinder.client.UiField;
 import com.google.gwt.uibinder.client.UiHandler;
 import com.google.gwt.user.client.Timer;
+import com.google.gwt.user.client.Window;
 import com.google.gwt.user.client.rpc.AsyncCallback;
 import com.google.gwt.user.client.ui.Composite;
 import com.google.gwt.user.client.ui.Widget;
@@ -64,47 +65,62 @@ public class FormViewImpl extends Composite implements FormView, Editor<FormView
 	ControlGroup nameGroup;
 	@UiField
 	ControlGroup feedbackGroup;
-	
+
 	public FormViewImpl(Delegate delegate) {
 		super();
 		this.delegate = delegate;
 		initWidget(uiBinder.createAndBindUi(this));
 		driver.initialize(this);
 		driver.edit(new UserDetails());
-		
+
 		email.addKeyDownHandler(new KeyDownHandler() {			
 			@Override
 			public void onKeyDown(KeyDownEvent event) {
-				 if (event.getNativeKeyCode() == KeyCodes.KEY_ENTER)
-			            openModal.click();				
+				if (event.getNativeKeyCode() == KeyCodes.KEY_ENTER)
+					openModal.click();				
 			}
 		});
-		
+
 		name.addKeyDownHandler(new KeyDownHandler() {			
 			@Override
 			public void onKeyDown(KeyDownEvent event) {
-				 if (event.getNativeKeyCode() == KeyCodes.KEY_ENTER)
-					 sendInvite.click();				
+				if (event.getNativeKeyCode() == KeyCodes.KEY_ENTER)
+					sendInvite.click();				
 			}
 		});
-		
+
 		sendInvite.setEnabled(true);
 	}
 
 	@UiHandler("openModal")
 	void onUserClick(ClickEvent event) {
 		if (!delegate.onSendClick()) {
-			sendInvite.setEnabled(true);
-			feedback.setText("This gateway will send the invitation email to: "+email.getText() + " and put you in cc. It will never email your contacts without your consent.");
-			name.setText("");
-			modalWindow.show();
-			Timer t = new Timer() {				
+			service.accountExistInVRE(email.getText(), new AsyncCallback<Boolean>() {
 				@Override
-				public void run() {
-					name.setFocus(true);					
+				public void onFailure(Throwable caught) {
+					Window.alert("Ops, There were problems communicating with the server, please retry later or report this issue to http://support.d4science.org");				
 				}
-			};
-			t.schedule(1000);
+
+				@Override
+				public void onSuccess(Boolean userAccountExists) {
+					if (userAccountExists) {
+						Window.alert("A user with the same email already exists in this VRE, the invite cannot be sent.");
+					} else {
+						sendInvite.setEnabled(true);
+						feedback.setText("This gateway will send the invitation email to: "+email.getText() + " and put you in cc. It will never email your contacts without your consent.");
+						name.setText("");
+						modalWindow.show();
+						Timer t = new Timer() {				
+							@Override
+							public void run() {
+								name.setFocus(true);					
+							}
+						};
+						t.schedule(1000);	
+					}
+				}
+			});
+
 		}
 	}
 
